---
title: "The One, the Many, and the Liberal"
date: 2022-08-28T21:49:07+01:00
tags: ["Universals", "Particulars", "Parmenides", "Liberalism", "Secularism", "Aristotle"]
topics: ["metaphysics", "politics"]
image: img/one-and-many-resized.jpg
description: A research notebook investigating Liberalism and its obsolescence
draft: false
---
### Obsolescence and Liberalism

This weekend's theme asks us to consider whether we think *Liberalism* is *obsolete*. What does this question mean? What are we really trying to get at, when we ask this question? Let us take note that there are two rather expansive and indeterminate words in this question; indeterminate, because of the way the question has been asked. Namely, the words *Liberalism*, and *obsolete*.

It is out of fashion these days to begin a philosophy talk with definitions, but I cannot help but do so in this case, because otherwise you will have no idea what I am asking you to agree to in this argument. So, let us begin with the word obsolete. According to the Oxford English Dictionary, obsolete means "*out of fashion, because no longer useful*". Well, if that is true, then the immediate question that arises from this is, no longer useful to whom? and for what?

To answer those questions we need to tackle the second term, *Liberalism*. There is no sufficient single dictionary definition for this word. The Oxford Advanced Learner's dictionary, for example, will tell you that it is more or less synonymous with a kind of libertine moral relativism: "*willing to understand and respect other people’s behaviour, opinions, etc., especially when they are different from your own; believing people should be able to choose how they behave*". The fact that this definition doesn't absolutely scandalise us today, is a testament to just how pervasive liberal ideology is, in the Anglo-American west.

Encyclopedia Britannica give us a slightly more refined specification, as a "*political doctrine that takes protecting and enhancing the freedom of the individual to be the central problem of politics*", and the Stanford Encyclopedia of Philosophy quotes John Locke largely agreeing with Britannica, that "[Liberals have typically maintained that humans are naturally in] *a State of perfect Freedom to order their own actions…as they think fit…without asking leave, or depending on the Will of any other Man...* " and that "*...the burden of proof is supposed to be with those who are against liberty; who contend for any restriction or prohibition…. the a priori assumption is in favour of freedom…*". Max Savelle, a political historian writing mid-century, seems to agree with this rough idea:

>  "Liberalism... [is defined as] a self-conscious ideology of self-determination resting upon the assumption that the individual human intelligence is autonomous and that the progress of civilisation derives from the use of this autonomous intelligence in the efforts of humanity to survive and live the good life..." ~ Max Savelle, "Is Liberalism Dead?", November 1957

So, now we have a more or less clear understanding of what Liberalism is, and to what end Liberalism is supposed to be the means. The end is the freedom to define for oneself what *the good life* amounts to, and the the method is the placement of the individual beyond the reach of either a judging or constraining authority. Liberalism, then, is purported to be useful for achieving human freedom as against an obstructing authority, and the question of the weekend is whether or not the method of individualism is no longer useful for achieving that end.

But once again, I am vexed by new questions. In the first place, why should the individual be treated as the focal point of analysis in politics? What makes the individual a reasonable unit of analysis, given the myriad of other options? Some will say, well, because it is the frame that best enables the expansion of freedom. Then I will ask my second question: freedom... *to do what*? *And, to what end*? What considerations ought I account for, when deciding how to act and which ends to pursue in those actions? Without reference or appeal to some common standard of truth, what could it even mean to "define the good life for oneself"? Or, am I to take the Oxford Learner's Dictionary as an advice column, and just do whatever comes to mind, simply because everyone has to "respect" it (whatever the action)?

There are some who will answer with an emphatic yes, to the last question. For them, Liberalism is indeed about the total liberation of the individual will from all constraints, both natural and artificial. On this view, not only is Liberalism obsolete, it is hard to see how it could ever have been effective at this goal in the first place. But even if this sort of ideally absolute liberation were possible in the material world, it still doesn't answer my core concern, which is: *what am I to do with this vast landscape of general action and unspecified choices*? Without a definite goal grounded in an idea of what I am and how I fit into the universe, and conditioning a hierarchy of values below it, every action is as meaningful and as worth pursuing, as any other. Which is to say, not at all. For, being liberated from all constraints and concerns, what could possibly be worth pursuing after that? I am reminded of Ayn Rand's indestructible robot.

If, on the other hand, we wish to back away from these sorts of absolutes, and we want to recognise that there are limits to liberty, then the next question becomes, what sort of constraints upon liberty would be just constraints? That, of course, will require a conception of justice, and that in turn, will require an understanding of the good in a universal sense. Justice and The Good, will then rest in a conceptual hierarchy over and above liberty, characterising whole ranges of choice as either just or unjust insofar as they conform to the ultimate end, The Good. On this view, however, the liberty of the individual cannot be the "central problem of politics", but rather, knowing The Good, and defining justice in terms of it. And here, finally, we find that Liberalism is fundamentally incoherent (let alone obsolete), and that we are once again back in the arms of Plato and Aristotle, grappling with the core questions of philosophy.

### Plato And Divine Order

Plato's dialogue The Parmenides is an account of an dialogue between Socrates' and the great Greek master, Parmenides. Socrates was in his early career at the time, and sought to impress the elder with his theory of The Forms. Parmenides, of course, handed Socrates a big basket of embarrassing failures and sent him on his way. The point here, is not to re-adjudicate the Theory of Forms, but to posit an answer as to why this dialogue was written in the first place.

Some scholars will tell you it is because Plato was beginning to question the doctrine of the Forms. Others, that he wanted to demonstrate that the dialectic could go in both directions. I think, however, that Plato spent his life grappling with the puzzle that Parmenides had left behind, and the Theory of Forms was just his way of trying to come to terms with the problem. Dialogues like the Timaeus are obvious examples of his speculative romps in search of a metaphysics that reconciled The One with The Many.

Plato's best and most relevant attempt at this reconciliation is not the Timaeus or the Parmenides, but The Republic. In book two, at the outset of the investigation into Justice, Plato  gives us an exchange between Adiemantus and Socrates, that is clearly telegraphing the desire to reconcile The One and The Many:

> Socrates: "...Justice, which is the subject of our inquiry, is as you know, sometimes spoken of as the virtue of an individual, and sometimes as the virtue of a polis... [and it is true that] a polis is larger than an individual... I propose therefore, that we inquire into the nature of justice and injustice, first as they appear in the polis, and secondly in the individual, proceeding from the greater to the lesser... A polis, I said, arises... out of the needs of mankind; no one is self-sufficing, but all of us have many wants.... and [as] many persons are needed to supply them, one takes a helper for one purpose and another for another purpose; and when these partners and helpers are gathered together in one habitation the body of the inhabitants is termed a State... and they exchange with one another, and one gives, and another receives, under the idea that the exchange will be for their good...." Plato, The Republic, Book 2

As we'll see in a moment, this sounds very similar to Aristotle's Politics (which is no surprise, by itself). The most obvious commonality between the two, is that *telos* is the first cause of all things. It is *purposes* or *final cause* that give rise to new Forms. The excellence of those forms (aka their virtue, or perfection) is measured in terms of their capacity to fulfil their ends.

Aristotle would agree that the end of the state is the excellence of mankind. Where Plato parts with Aristotle, however, is in the explanatory direction of *telos*. Plato begins with an ordained order, discerned through dialectic and the discipline of reason, and the many parts of the polis are to conform to that order to be just. This is why his explanation of justice begins with the State, and is then transferred by analogy to the individual. It is the universal order as it is manifest in the ideal state, that is to be the model of right order of the individual soul. And this is what is, for Plato, the reconciliation of The One and The Many: the right ordering of the soul in accordance with the universal soul.

### Aristotle And Natural Order

Aristotle's political order, like Plato's, is a product of his metaphysics and his methodology for inferring the truth. Unlike Plato, however, Aristotle's methodology was not dialectic, but analytic and empirical, beginning with particulars, and seeking The One that unifies them, by powers of observation and inference to the general. Everything is analyzed into categories according to their essential commonalities, and confirmed by empirical investigation. Aristotle always starts with individuals arranged into categories, and this method carries into his political philosophy:

> "Every polis is as we see a sort of partnership, and every partnership is formed with a view to some good (since all actions of all mankind are done with a view to what they think is good). It is therefore evident that, while all partnerships aim at some good, the partnership that is the most supreme of all and includes all the others does so most of all, and aims at the most supreme of all goods; and this is the partnership entitled the polis, the political association." Aristotle, Politics I. i.1

So, there are different categories of social association, and each category is different in kind from the other, and they are ordered hierarchically by the kind of good they pursue. The state is at the top of the hierarchy, because it is the association which seeks the *summum bonum* for man. All others fall below it in importance.

> "In every other matter it is necessary to analyse the composite whole down to its uncompounded elements (for these are the smallest parts of the whole); so too with the polis, by examining the elements of which it is composed we shall better discern in relation to these different kinds of rulers what is the difference between them, and whether it is possible to obtain any scientific precision..." Politics I.i.3

To discover whether this hierarchical picture is accurate, we must reduce the association to its component parts and look for the component that makes each association *essentially* different from the others -- just as we did for biological organisms. What's more, just as we did for biological organisms, the best approach to discovering these categorical differences in associations, is to trace their development, from generation to full actualization.

> "The partnership therefore that comes about in the course of nature for everyday purposes is the oikos; the persons who Charondas speaks of as 'meal-tub-fellows' and the Cretan Epimenides as 'manger-fellows'" Politics, II

So, it is not the *individual*, but the *household* that is the basic atom of politics. The fundamental unit of analysis. What's more, it is not the household of 20th century life. It is a household comprised of wife, children, hired help (such as midwives and farm managers), and slaves.

> "the primary partnership made up of several oikos for the satisfaction of not merely daily needs is the village. The village according to the most natural account seems to be a colony from a household, formed of those whom speak of as 'fellow nurselings', sons and sons' sons" Politics, II

The natural practice of populating the earth, then, is a process of colonization, where a subset of a household homesteads a new space, and a subset of a village founds a new village, and a subset of a polis founds a new polis.

> "It is owing to this that our [poleis] were at first under royal sway and that foreign races are so still, because they were made up of parts that were under royal rule; for every household is under royal rule of its elder member, so that the colonies from the household were so too, because of the kinship of their members. And this is what Homer means: *And each one gives law to sons and labor to spouses--*" Politics, II

That last bit is stated in passing. But it is essential. The law is *given* to sons. The sons do not *make* their own law. They *inherit* the law from their elders, who did the same, and so on, back to the point that it was handed to them by someone who could discern the law from the Gods, and from nature. Men like Solon, for example. Solon was called the great *lawgiver*, not the great *lawmaker*.

> "why man is a political animal in a greater measure than any bee or any gregarious animal is clear. For nature, as we declare, does nothing without purpose; and man alone of the animals possesses speech. The mere voice, it is true, can indicate pain and pleasure, and therefore it is possessed by the other animals as well (for their nature has been developed so far as to have sensations of what is painful and pleasant and to signify those sensations to one another), but speech is designed to indicate the advantageous and the harmful, and therefore the right and the wrong; for it is the special property of man in distinction from the other animals that he alone has perception of good and bad and right and wrong and the other moral qualities, and it is partnership in these things that makes a household and a polis."

So again, the discernment and pursuit of excellence is what defines the essence of an oikos and a polis. The excellence pursued is going to be different for each kind of partnership, because each has a different *telos*. One, the actualisation of a family, the other, the actualisation of a community (and as we shall soon see, the excellence of each man). But again, *the good* is to be found in the nature of the thing, and discerned from its function.

> "The polis is prior in nature to the household... For the whole must necessarily be prior to the part; since when  the whole body is destroyed, foot or hand will not exist except in an equivocal sense... and all things are defined by their function and capacity, so that when they are no longer such as to perform their function they must not be said to be the same things, but to bear their names in an equivocal sense. It is clear therefore that the polis is also prior by nature to the individual; for if each individual when separate is not self-sufficient, he must be related to the whole polis as other parts are to their whole, while a man who is incapable of entering into partnership, or who is so self-sufficing that he has no need to do so, is no part of a polis, so that he must be either a lower animal, or a god. Therefore, the impulse to form a partnership of this kind is present in all men by nature; but the man who first united people in such a partnership was the greatest of benefactors. For as man is the best of the animals when perfected, so he is the worst of them when sundered from law and justice."

Aristotle, again agreeing with Plato, says the polis is "prior to" the household, because the polis is the *telos* of the household -- the final cause. Why? Because the composition of households into a village, and villages into a polis, is necessary for the full actualisation of man, which is only possible where justice is possible, and justice is only possible where a polis has formed.

So, the polis makes possible the actualisation of justice through the process of the social discovery of rules and standards, by way of judicial procedure. That, in turn, functions as a regulatory mechanism on the polis as well as on the villages and families, and balance is struck between the parts and the whole, through justice discerned from the nature and function of both the whole and the parts, but again, placing the polis in the command position, as a part of its nature:

> "Authority and subordination are conditions not only inevitable but also expedient; in some cases things are marked out from the moment of birth to rule or be ruled. And there are many varieties both of rules and of subjects -- and the higher the type of the subjects, the loftier is the nature of the authority exercised over them, for example to command a human being is a higher thing than to tame a wild beast; for the higher the type of the parties to the performance of a function, the higher is the function, and when one party rules and another is ruled, there is a function performed between them) -- because in every composite thing, where a plurality of parts, whether continuous or discrete, is combined to make a single common whole, there is always a ruling and a subject factor, and this characteristic of living things is present in them as an outcome of the whole of nature, since even the things that do not partake of life there is a ruling principle, as in the case of a musical scale..."

The reference to the ruling principle of the musical scale is again a passing comment, but again essential to the explanation of order, for Aristotle. You do not invent order. You do not impose it by fiat. You observe the way things work in practice, and you infer general principles of order from observations.

Here, we also see a reconfiguration of the Platonic model of the soul. Rather than an independent dualistic soul constituted from three parts (intellect, conscience, and appetite) and "entrapped" by the body, now we have a soul that is the master ordering principle of the body. The "form" of the matter that consists in the body, and the "essence" of the substance of the individual man. On this view, intellect and the appetite exist in a hierarchical "constitutional" order, in which the intellect discerns the Formal order of the soul, and then "tames" the appetites to conform to that rule.

The Platonic sense of the soul being entrapped by the body, is an analogy of the individual being duty-bound by his role within the polis. For Aristotle, however, there is an upturning of the explanation of man's purpose in terms of his placement within the city, by explaining the city in terms of it's function in the perfection of the man. For Plato, the polis is the ruling principle, because it is the exemplar of ideal order to which man must conform for the sake of the good itself. But, for Aristotle, the polis is the ruling principle of the individuals that constitute it, because it is the organ that seeks the summum bonum for all the parts, individually.

Thus, political philosophy for the ancient Greeks was the discipline (or science) of discerning the nature of justice from the order of the universe, and providing a method by which statesmen and politicians could pronounce that order in a way befitting of the customs and practices of the day. A process not dissimilar to a theocratic rule, except that the theos was discerned by means of reason, rather than by revelation.

Eventually, the neo-Platonists, and then the Christians after them, reoriented the *summum bonum* once again, from the mere earthly excellence of Aristotle, to a *telos* that amounts to absolute reunion with the Godhead, in an attempt to reassert The One over the many polei with which Aristotle had left them grappling. To do this, they couple both reason and revelation together in a kind of cooperative venture. As Aquinas put it, we were to understand what could be by nature, and grace would take us the rest of the way.

### The Rise of Liberalism And The Schism With The One

However, while the temporary resurgence of Platonism did reintroduce the absolute and the transcendent back into Aristotle's worryingly pluralistic immanent order,  his original inversion of explanation lingered, and it haunted thinkers as early as Thomas Aquinas, who in his *De Regno* of 1267, marshals Aristotle in defence of collective order:

> "..*.the light of reason is placed by nature in every man, to guide him in his acts toward his end. Wherefore, if man were intended to live alone, as the animals do, he would require no other guide to his end. Each man would be a king unto himself, under God, the highest King, inasmuch as he would direct himself in his acts by the light of reason given him from on high. Yet it is the nature of man, more than any other animal, to be a social and political animal, to live in a group... For all other animals, nature has prepared food, hair as a covering, teeth, horns, claws, as a means of defence or at least speed in flight, while man alone was made without any natural provisions for these things. Instead of these, man was endowed with reason, by the use of which he could procure all these things for himself by the work of his hands. Now, one man alone is not able to procure them all for himself, for one man could not sufficiently provide for life [or attain his ultimate end] unassisted. It is therefore natural that man should live in the society of many*..." Thomas Aquinas, De Regno, 1267

Later, Dante, borrowing heavily (though only implicitly) from Plotinus in his 1321 essay *De Monarchia*, makes a much more vigorous attempt to reframe Aristotle's Politics into a doctrine of right order, according to the principle of unity understood as God himself.

> *"[Aristotle] asserts that when several things are ordained for one end, one of them must regulate or rule, and the others must submit to regulation or rule... If we consider the individual man, we shall see that this applies to him, for, when all his faculties are ordered for his happiness, the intellectual faculty itself is regulator and ruler of all others; in no way else can man attain to happiness.... We are now agreed that the whole human race is ordered for one end... it is meet, therefore, that the leader and lord be one... [and] for the well being of the world there is needed a Monarchy..."* De Regno, 1267

And the chief monarch, of course, is God:

> *"...Everything is well, nay, best disposed which acts in accordance with the intention of the first agent, who is God. This is self-evident, save to such as deny that divine goodness attains the summit of perfection. It is of the intention of God that all things should represent the divine likeness in so far as their peculiar nature is able to receive it... The human race, therefore, is ordered well, nay, is ordered for the best, when according to the utmost of its power it becomes like unto God. But the human race is most like unto God when it is most one, for the principle of unity dwells in Him alone... Likewise, every son acts well and for the best when, as far as his individual nature permits, he follows in the footprints of the perfect father."* Dante, De Monarchia, 1321

But the way Dante accomplished this harmony with the Divine Monarch, was by way of an elevation of human reason, in a way that Plato and Aristotle very likely would have recognised immediately, but must have made the Catholic church extremely uncomfortable:

> *"...the proper function of the human race, taken in the aggregate, is to actualise continually the entire capacity of the possible intellect, primarily in speculation; then, through its extension and for its sake, secondarily in action. Since it is true that whatever modifies a part modifies the whole, and that the individual man seated in quiet grows perfect in knowledge and wisdom, it is plain that amid the calm and tranquillity of peace the human race accomplishes most freely and easily its given work... universal peace is the best of those things which are ordained for our beatitude."* De Monarchia, 1321

And here, even in Dante, we can detect the first faint odours of Liberal individualism rising out of the vapours of ancient Greece, but flavoured by Catholic Scholasticism. Only a hundred and fifty years later, one man would take up Aquinas' concern as a "challenge accepted", obliterating Dante's divine reason in the process and setting the stage for a Reformation. Pico della Mirandola, professed the following in a speech written for a group gathering that was to occur in Rome in 1487 (but never happened, because Mirandola was chased out by the Pope, for causing a scandal around some of his other writings). Here, however, he writes:

> *At last, the Best of Artisans... accorded to Man the function of a form not set apart, and a place in the middle of the world, and addressed him thus: Ί have given thee neither a fixed abode nor a form that is thine alone nor any function peculiar to thyself, Adam, to the end that, according to thy longing and according to thy judgement, thou mayest have and possess that abode, that form, and those functions which thou thyself shalt desire. The nature of all other things is limited and constrained within the bounds prescribed by me: thou, coerced by no necessity, shalt ordain for thyself the limits of thy nature in accordance with thine own free will, in whose hand I have placed thee. . . . Thou shalt have the power to degenerate into the lower forms of life, which are animal; thou shalt have the power, out of thy soul's judgement, to be reborn into the higher forms of life, which are divine.* ~ Pico della Mirandola, "Of The Dignity of Man", 1486

And from there, we were off to the races.. As Reinhold Niebur put it:

> "the Renaissance uses an idea which could have grown only on the soil of Christianity. It transplants this idea to the soil of classical rationalism to produce a new concept of individual autonomy, which is known in neither classicism nor Christianity." Reinhold Niebur, 1941

### The Death of God and the Divinization of Man

So, given this new concept of the autonomous individual, is it really any wonder that by 1650, we have Descartes nonchalantly  internalizing the "light of reason" within his own skull, and birthing the wind-egg of the "Cartesian Circle" in the process. Or, also, Locke in 1690, providing a justification from Genesis for absolute individual sovereignty in his less often cited *First Treatise*, in which God, being the creator of all things, is also the owner of all things, and by analogy we as creators are owners of that which we create. And, by 1793, we can see a defiant anti-authoritarian intellectual individualism in Thomas Paine's famous "The Age of Reason":

> *"I believe in one God, and no more; and I hope for happiness beyond this life... But, lest it should be supposed that I believe many other things in addition to these, I shall, in the progress of this work, declare things I do not believe, and my reasons for not believing them. I do not believe in the creed professed by the Jewish church, by the Roman church, by the Greek church, by the Turkish church, by the Protestant church, nor by any church that I know of. My own mind is my own church."* ~ Thomas Paine, 1793

The ever-widening gap between The One and The Many had begun to skew our perspective. The One shrank from view, and the Many autonomous rational individuals began to rapidly grow in apparent size, until eventually we came to think that individual autonomy under the ruler-ship of God was not good enough, because a ruled subject that thinks he is free, is either a fool, or a liar. Thus, came the day we declared man himself to be a divine thing all by himself, without reference to God. His own mind was his own church, and now another 100  years after Paine, according to Emile Faguet, his own conscience was his own God:

> *"Man is sacred because he is a temple; he has divine rights because he is himself a divine thing; there is no social code against the code of his conscience; there is no collective right against his individual duty"* ~ Emile Faguet, 1891

But Gods are jealous things. So, either God had to go or the divine self had to, and so, we chose to banish God.

> *"Where has God gone?... I mean to tell you! We have killed him -- you and I! We are all his murderers!... Do we not hear the noise of the grave-diggers who are burying God even now? Do we not smell the divine putrefaction? For even Gods putrefy! God is dead! God remains dead! And we have killed him!"*, Friedrich Nietzsche, 1882

And finally, it is still not enough to simply do away with The One and declare ourselves the victorious absolute ends. For a God without any power, is a God in name only. So, less than 75 years after Nietzsche we began the process of attributing to this atomised Nietzschean New Man, the very power of the God we killed. Both the power of destruction:

> *We knew the world would not be the same. A few people laughed, a few people cried, most people were silent. I remembered the line from the Hindu scripture, the Bhagavad-Gita. Vishnu is trying to persuade the Prince that he should do his duty and to impress him takes on his multi-armed form and says, “Now, I am become Death, the destroyer of worlds.” I suppose we all thought that one way or another*. - J. Robert Oppenheimer, 1945

And creation:

> *These matters, involving the most intimate and personal choices a person may make in a lifetime, choices central to personal dignity and autonomy, are central to the liberty protected by the Fourteenth Amendment. At the heart of liberty is the right to define one's own concept of existence, of meaning, of the universe, and of the mystery of human life. Beliefs about these matters could not define the attributes of personhood were they formed under compulsion of the State.* -- Planned Parenthood v Casey, US Supreme Court, 1992 (O'Connor, Kennedy, and Souter)

We have obliterated The One, and subsumed him into ourselves. We all now live in self-styled universes, each of our own creation, where we can tailor not only our surroundings, but customize to arbitrary will, our very nature as beings, including the boutique mangling of the human body itself to suit one's taste in any given moment; and if some prognosticators are correct, the eventual power to transplant raw identity (dare I say, soul) into any vessel one desires.

But as I said before, Gods are very jealous things. They do not tolerate plurality well, and the liberation of the human will and its ascendance to Godhood is coming at a great cost. The whole of the twentieth century was a constant oscillation between this ecstatic individualism, and reactionary totalitarian collectivism, as so-called liberals and progressives fought over who would define the new *telos* for man. For, now that we are no longer taking our cues from nature, or the divine Godhead, we are free to invent our own purposes. And invent we do. And then war over it. In the midst of all of this, in 1938, Liberal philosopher Jacques Maritain had this to say about what was going on:

> "With the triumph of rationalism and liberalism, i.e., of a philosophy of freedom which makes of each abstract individual and his opinions the source of all right and truth, *spiritual unity* has 'gone west'; we have ourselves been able to experience the benefits of this dispersion. But this individualistic liberalism was palpably a purely *negative* energy; it lived by its opposite and because of it. Once the obstacle has fallen, it lacks any support." ~ Jacques Maritain, "True Humanism", 151-152, 1938

Maritain was fretting over the fact that Liberalism appeared to him to be a reaction against something he could not quite define, and feared the collapse of Liberalism in the face of the absence of that threat. He naturally sensed the diminishing presence of The One, and intuitively understood that without the natural tension between The One and The Many, The Many would consume itself in an orgy of purposelessness.

To be sure, Maritain was a triumphal Liberal. His book is basically posing the question: "We're winning, but then what?" If what I have been saying so far is correct, then what you've won is either the anarchy of Hobbes, in which a war of every self-styled God against every other ends in complete catastrophe; or you've won the forced collectivization of mankind into a materialist eschatology, the likes of which Marx and others have tried to construct in place of religion. Charles Frankel puts the case in more hopeful terms in 1955 for you:

> "The great problem... is to reconstruct the liberal tradition to make it applicable to an age of technical specialization, bureaucratized power, and mass movements.. .. The revival of liberal hopes depends upon their being attached to specific programs and definite objectives... For the revolution of modernity... has been a moral revolution of extraordinary scope, a radical alteration in what the human imagination is prepared to envisage and demand. ... it has set loose the restless vision of a world in which men might be liberated from age-old burdens, and come to set their own standards and govern their own lives" - Charles Frankel, The Case For Modern Man, 1955

What this means in practice, is a world in which there is a rigid ordering and a clear telos toward which that order is directed. Only this time, that ordering is not along the lines of the transcendent One, as understood through Christian Theology, or even Greek philosophy, but as an arbitrary expressions of spurious pangs of conscience in particular individuals with political power, as Thomas Neill writes in 1953:

>  "Liberalism's moral values are likewise derived from the Christian tradition... [it's] strength lay in its taking nourishment from the Christian tradition... But Liberalism changed these ideas, sometimes weakening them, sometimes twisting them to serve different ends... Liberalism kept the old Christian ideas of man's worth, of his dignity, rationality, and freedom, but it rejected the traditional explanation of these ideas in favor of more modern views. Early in the century Liberals paradoxically set forth an ideal that was spiritual in nature, while accepting a materialistic explanation of man and the universe. By the end of the century they asked for social legislation and various forms of protection -- but for servile, nonspiritual ends. Liberalism had renounced its ideals in favor of material comforts... In reducing men to a collective of isolated atoms it stripped them of their supporting associations, and finally it left them standing naked before the State... To the State, then, countless thousands began to turn for protection..." Thomas P. Neill, The Rise And Decline of Liberalism, 1953

And Liberals themselves started to notice this as a potentially serious problem, as early as the mid-century. With the disasters of both Communism and radical Nationalism still looming large, Max Savelle wrote the following in 1957:

> "whereas the liberals of the nineteenth century fought for the protection of the individual against the State, those of the twentieth came to depend upon the state to defend society against the all-too-rugged individual as well as against the imponderable forces of history over which the individual, however free, had no control. Now, it is the State itself that they fear." Max Savelle, 1957

Worse yet, Savelle writes, we have seen the enemy, and he is us:

> "It is the people who are the State; and the government, in the steady and progressive extension of its powers, apparently has actually obeyed the wishes of the people, rather than imposed its will upon them. As democracy -- conceived here as the control of the machinery of government by the people -- has become more and more of a reality, its mood has appeared to move progressively *away* from the... individualism of the nineteenth century toward a progressively more extensive and more effective collectivism in outlook." Max Savelle, 1957

This point is echoed loudly in Ruben Alverado's commendable little book "Common Law and Natural Rights", written in 2009 as a defense of the prescriptive English Common Law tradition of individual rights, over and against the Liberal Natural Rights doctrine. We can hear the echoes of Aristotle in Alverado's protest:

> "liberty is not *just there*, as a pre-existing condition to be preserved by civil government, to which all are entitled simply by virtue of their humanity; much rather, it is a birthright, an heirloom. It is the product of centuries of labor within the context of specifically Western civilization" Alverado, Common Law and Natural Rights, 2009

Like the "sons" of Aristotle's Politics, Alverado argues that Law is *given*, not *made*. But, Alverado laments, that is not the world we live in today. We no longer seek the law in either nature or God, but within ourselves:

> "Majorities have been conditioned to believe whatever they decide upon, that is, whatever their will may be, *is law*. The understanding of law as something standing over and conditioning sovereignty has been lost... With sovereignty having been given this absolute, above-the-law air, we get representative bodies charged with carrying out the will of this absolute sovereign. This establishes a vortex of power wherein politicians are encouraged to bid up their promises to carry out the wishes of the sovereign people...  " Alverado, Common Law and Natural Rights, 2009

So, again here, we have the sacred, sovereign self, surfacing in modern politics as an absolute ruler in the form of a democratic polity whose will *just is The Law*, and tradition and principle be damned if it gets in the way. This is how the oscillation occurs. A constant push and pull of action-reaction, between the collectivists and the libertines, each with his own synthetic materialist eschatology, and each with his own absolute, inviolable will, necessarily irreconcilable with any around him, because to reconcile would be to admit a unifying authority over and above the individual, the necessary rejection of which, according to Liberals, and as we have heard from Encyclopedia Britannica, is "the central problem of politics".

### Conclusion

Thus, Liberalism is not obsolete. Many of its defenders today claim Liberalism is the solution to the very problem Liberalism created in 1487 (if we want to put an arbitrary historical pin on it). Its defenders often don't even realise that they're defending the problem against itself.

Liberalism is wrong, because it *personalises* universal principles into self-justifications meant to stand outside the judgement of universal principle. Which makes it incoherent at best, and as we have seen throughout the 19th and 20th centuries, catastrophically dangerous at worst.

But don't confuse this essay as an unqualified defence of The One as a singular rule of political order, either. The interesting thing about the paradox of The One and The Many, is precisely that there is no resolution. Wisdom lies in learning to cope with both. Yet, the wisdom to know when to expect unity and when to expect plurality, is something this generation seems to have lost. It demands either one, or the other because it lacks the intellectual maturity to understand the problem.

The present monomania of modern identity politics seems to indicate that there is no stopping the juggernaut of self-deification. So, for those of you worried that Liberalism might be obsolete, you take heart in the fact that the cancer has metastasised, and is inoperable. Obsolete or not, it's not going away, and its consequences are virtually inevitable. The real question, will we survive those consequences, and if we do, what will happen afterwards? 
